/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.eclipse.sphinx.jdt.loaders;

import org.eclipse.core.runtime.Assert;
import org.eclipse.xtext.xbase.lib.Exceptions;

@SuppressWarnings("all")
public class DelegatingClassLoader extends ClassLoader {
  private ClassLoader delegate;
  
  public DelegatingClassLoader(final ClassLoader parent, final ClassLoader delegate) {
    super(parent);
    Assert.isNotNull(delegate);
    this.delegate = delegate;
  }
  
  public Class<?> findClass(final String name) {
    try {
      return this.delegate.loadClass(name);
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public String toString() {
    Class<? extends DelegatingClassLoader> _class = this.getClass();
    String _simpleName = _class.getSimpleName();
    String _plus = (_simpleName + " [delegate=");
    String _plus_1 = (_plus + this.delegate);
    return (_plus_1 + "]");
  }
}
