/**
 * <copyright>
 * 
 * Copyright (c) 2014 itemis and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     itemis - Initial API and implementation
 * 
 * </copyright>
 */
package org.eclipse.sphinx.jdt.util;

import com.google.common.base.Objects;
import java.io.File;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.Assert;
import org.eclipse.core.runtime.IPath;
import org.eclipse.jdt.core.IClasspathEntry;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.jdt.launching.IVMInstall;
import org.eclipse.jdt.launching.IVMInstall2;
import org.eclipse.jdt.launching.JavaRuntime;
import org.eclipse.osgi.util.NLS;
import org.eclipse.sphinx.jdt.internal.Activator;
import org.eclipse.sphinx.jdt.internal.messages.Messages;
import org.eclipse.sphinx.platform.util.PlatformLogUtil;
import org.eclipse.xtext.xbase.lib.Exceptions;

@SuppressWarnings("all")
public class JavaExtensions {
  public static File getFile(final IClasspathEntry entry) {
    File _xifexpression = null;
    IPath _path = entry.getPath();
    File _file = _path.toFile();
    boolean _exists = _file.exists();
    if (_exists) {
      IPath _path_1 = entry.getPath();
      _xifexpression = _path_1.toFile();
    } else {
      IWorkspace _workspace = ResourcesPlugin.getWorkspace();
      IWorkspaceRoot _root = _workspace.getRoot();
      IPath _location = _root.getLocation();
      IPath _path_2 = entry.getPath();
      IPath _append = _location.append(_path_2);
      _xifexpression = _append.toFile();
    }
    return _xifexpression;
  }
  
  public static IJavaProject getJavaProject(final String projectName) {
    IWorkspace _workspace = ResourcesPlugin.getWorkspace();
    IWorkspaceRoot _root = _workspace.getRoot();
    IProject _project = _root.getProject(projectName);
    return JavaCore.create(_project);
  }
  
  /**
   * Returns the absolute path in the local file system corresponding to given workspace-relative path.
   * 
   * @param workspacePath the workspace-relative path to some resource in the workspace
   * 
   * @return the absolute path in the local file system corresponding to given <code>workspacePath</code>, or null if no path can be determined
   */
  public static IPath getLocation(final IPath workspacePath) {
    IWorkspace _workspace = ResourcesPlugin.getWorkspace();
    IWorkspaceRoot _root = _workspace.getRoot();
    IResource _findMember = _root.findMember(workspacePath);
    IPath _location = null;
    if (_findMember!=null) {
      _location=_findMember.getLocation();
    }
    return _location;
  }
  
  public static void validateCompilerCompliance(final String compliance) {
    final IVMInstall install = JavaRuntime.getDefaultVMInstall();
    if ((install instanceof IVMInstall2)) {
      final String compilerCompliance = JavaExtensions.getCompilerCompliance(((IVMInstall2)install), compliance);
      boolean _equals = compilerCompliance.equals(compliance);
      boolean _not = (!_equals);
      if (_not) {
        try {
          final float complianceToSet = Float.parseFloat(compliance);
          final float complianceFromVM = Float.parseFloat(compilerCompliance);
          String _bind = NLS.bind(Messages.error_JRECompliance_NotCompatible, compliance, compilerCompliance);
          Assert.isLegal((complianceToSet <= complianceFromVM), _bind);
        } catch (final Throwable _t) {
          if (_t instanceof NumberFormatException) {
            final NumberFormatException ex = (NumberFormatException)_t;
            Activator _default = Activator.getDefault();
            PlatformLogUtil.logAsWarning(_default, ex);
          } else {
            throw Exceptions.sneakyThrow(_t);
          }
        }
      }
    }
  }
  
  private static String getCompilerCompliance(final IVMInstall2 vMInstall, final String defaultCompliance) {
    Assert.isNotNull(vMInstall);
    final String version = vMInstall.getJavaVersion();
    boolean _equals = Objects.equal(version, null);
    if (_equals) {
      return defaultCompliance;
    } else {
      boolean _startsWith = version.startsWith(JavaCore.VERSION_1_8);
      if (_startsWith) {
        return JavaCore.VERSION_1_8;
      } else {
        boolean _startsWith_1 = version.startsWith(JavaCore.VERSION_1_7);
        if (_startsWith_1) {
          return JavaCore.VERSION_1_7;
        } else {
          boolean _startsWith_2 = version.startsWith(JavaCore.VERSION_1_6);
          if (_startsWith_2) {
            return JavaCore.VERSION_1_6;
          } else {
            boolean _startsWith_3 = version.startsWith(JavaCore.VERSION_1_5);
            if (_startsWith_3) {
              return JavaCore.VERSION_1_5;
            } else {
              boolean _startsWith_4 = version.startsWith(JavaCore.VERSION_1_4);
              if (_startsWith_4) {
                return JavaCore.VERSION_1_4;
              } else {
                boolean _startsWith_5 = version.startsWith(JavaCore.VERSION_1_3);
                if (_startsWith_5) {
                  return JavaCore.VERSION_1_3;
                } else {
                  boolean _startsWith_6 = version.startsWith(JavaCore.VERSION_1_2);
                  if (_startsWith_6) {
                    return JavaCore.VERSION_1_3;
                  } else {
                    boolean _startsWith_7 = version.startsWith(JavaCore.VERSION_1_1);
                    if (_startsWith_7) {
                      return JavaCore.VERSION_1_3;
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    return defaultCompliance;
  }
}
